==> kbib-0.6.1.tar.gz: kbib-0.6.1/kbib/kbibsortdlg.h <==
/***************************************************************************
                          kbibsortdlg  -  description
                             -------------------
    begin                : Fri Nov 26 2004
    copyright            : (C) 2004 by Thach Nguyen
    email                : thach@dragon.thach.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBIBSORTDLG_H
#define KBIBSORTDLG_H

#include <kdialogbase.h>
#include <qgroupbox.h>
#include <qbuttongroup.h> 
#include <qradiobutton.h>
#include <qpixmap.h>

#include <qlabel.h>
#include <kcombobox.h> 



/**
@author Thach Nguyen
*/
class KBibSortDlg : public KDialogBase
{
Q_OBJECT
public:
    KBibSortDlg(QWidget *parent = 0, const char *name = 0);
    QString getFieldToSort();
    int sortOrder();
    ~KBibSortDlg();
    
private:
	QLabel *label, *label1, *label2;
	KComboBox  *fieldList;
	QGroupBox *groupBox;
	QButtonGroup *buttonGroup;
	QRadioButton *ascending;
	QRadioButton *descending;

};

#endif

==> kbib_0.6.5.orig.tar.gz: kbib-0.6.5/kbib/kbibsortdlg.h <==
/***************************************************************************
                          kbibsortdlg  -  description
                             -------------------
    begin                : Fri Nov 26 2004
    copyright            : (C) 2004 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBIBSORTDLG_H
#define KBIBSORTDLG_H

#include <kdialogbase.h>
#include <qgroupbox.h>
#include <qbuttongroup.h> 
#include <qradiobutton.h>
#include <qpixmap.h>

#include <qlabel.h>
#include <kcombobox.h> 



/**
@author Thach Nguyen
*/
class KBibSortDlg : public KDialogBase
{
Q_OBJECT
public:
    KBibSortDlg(QWidget *parent = 0, const char *name = 0);
    QString getFieldToSort();
    int sortOrder();
    ~KBibSortDlg();
    
private:
	QLabel *label, *label1, *label2;
	KComboBox  *fieldList;
	QGroupBox *groupBox;
	QButtonGroup *buttonGroup;
	QRadioButton *ascending;
	QRadioButton *descending;

};

#endif
